# spatula

**spatula** is a lightweight scraping framework, designed to encourage best practices and ease development and testing of scrapers.

[![PyPI version](https://badge.fury.io/py/spatula.svg)](https://badge.fury.io/py/spatula)

[![](https://readthedocs.org/projects/spatula/badge/?version=latest&style=flat)](https://spatula.readthedocs.org)
